@@ -11,7 +11,7 @@ import math
 import array
 import string
 
-import ConfigParser
+#import ConfigParser
 import os, os.path
 
 import data
@@ -44,13 +44,20 @@ def SetAlarm():
 
         event.alarm_time = records.AlarmTime_seconds #in seconds
 
-        action_snooze, action_stop = event.add_actions(2)
-        txt=_('Snooze')
-        action_snooze.label=str(txt.encode( "utf-8" ))
-        action_snooze.flags |= alarm.ACTION_WHEN_RESPONDED | alarm.ACTION_TYPE_SNOOZE
-        txt=_('Stop')
-        action_stop.label =str(txt.encode( "utf-8" ))
-        action_stop.flags |= alarm.ACTION_WHEN_RESPONDED | alarm.ACTION_TYPE_NOP
+        if(data.UseAlternativeAlarm==False): #use normal MAEMO alarm
+            action_snooze, action_stop = event.add_actions(2)
+            txt=_('Snooze')
+            action_snooze.label=str(txt.encode( "utf-8" ))
+            action_snooze.flags |= alarm.ACTION_WHEN_RESPONDED | alarm.ACTION_TYPE_SNOOZE
+            txt=_('Stop')
+            action_stop.label =str(txt.encode( "utf-8" ))
+            action_stop.flags |= alarm.ACTION_WHEN_RESPONDED | alarm.ACTION_TYPE_NOP
+        else: #use own (external) alarm
+            print "* Use external alarm: "+data.AlternativeAlarm
+            action_run = event.add_actions(1)[0]
+            action_run.flags |= alarm.ACTION_WHEN_TRIGGERED | alarm.ACTION_TYPE_EXEC
+            action_run.command = data.AlternativeAlarm
+
 
         data.AlarmID = alarm.add_event(event)
 
