@@ -637,8 +637,11 @@ def PrintRecordData(ShowArray=True):
     print "WakeUp_Song_Duration:",  records.WakeUp_Song_Duration
     print "WakeUp_Song_Volume:",  records.WakeUp_Song_Volume
 
+    print "UseAlternativeAlarm:", records.UseAlternativeAlarm
+    print "AlternativeAlarm:", records.AlternativeAlarm
+
     if(ShowArray==True):
         for i in range(0, records.Index): #print data of  records
             print records.arrData[0][i],  records.arrData[1][i],  records.arrData[2][i],  records.arrData[3][i],  records.arrData[4][i],  records.arrData[5][i],  records.arrData[6][i]
 
-    print "##########################################################"
\ No newline at end of file
+    print "##########################################################"
