@@ -37,6 +37,7 @@ if(data.debug==True): print "Languages:", DEFAULT_LANGUAGES
 # Try to get the languages from the default locale
 if(data.language==""):
     lc, encoding = locale.getdefaultlocale()
+    print "Locale:", lc, ", Encoding:", encoding
     if lc:
         languages = [lc]
 
@@ -45,6 +46,7 @@ if(data.language==""):
     data.language=a[0]
 else:
     languages=[data.language]
+    print "Locale:", data.language
 
 
 # Concat all languages (env + default locale),
@@ -67,3 +69,4 @@ language = gettext.translation (APP_NAME, mo_location, languages = languages, fa
 
 
 
+
